############################################################################
#
#  Program:         ARPACK
#
#  Module:          ARmake.inc
#
#  Purpose:         Top-level Definitions
#
#  Creation date:   February 22, 1996
#
#  Modified:
#
#  Send bug reports, comments or suggestions to arpack@caam.rice.edu
#
############################################################################
#
# %---------------------------------%
# |  SECTION 1: PATHS AND LIBRARIES |
# %---------------------------------%
#
# %---------------------------------------------------------%
# | The complete path to the top level of ARPACK directory, |
# | usually $(HOME)/ARPACK                                  |
# %---------------------------------------------------------%
#
PATH = /bin:$(bindir):$(libexecdir)/mvapich2/bin
home          = $(HOME)
#
#  %--------------------------------------%
#  | The platform identifier to suffix to |
#  | the end of library names             |
#  %--------------------------------------%
#
PLAT          = LINUX
#
#  %--------------------------------------------------------------%
#  | The communication library ( need for parallel library only ) |
#  | Current availible platforms are: BLACS or MPI                |
#  %--------------------------------------------------------------%
#
COMMLIB       = BLACS
#
#  %------------------------------------------------------%
#  | The directories to find the various pieces of ARPACK |
#  %------------------------------------------------------%
#
BLASdir      = $(home)/BLAS
LAPACKdir    = $(home)/LAPACK
UTILdir      = $(home)/UTIL
SRCdir       = $(home)/SRC
PSRCdir      = $(home)/PARPACK/SRC/$(COMMLIB)
PUTILdir     = $(home)/PARPACK/UTIL/$(COMMLIB)
#
DIRS   = $(BLASdir) $(LAPACKdir) $(UTILdir) $(SRCdir) 
#
# %-------------------------------------------------------------------%
# | Comment out the previous line and uncomment the following         |
# | if you already have the BLAS and LAPACK installed on your system. |
# | NOTE: ARPACK assumes the use of LAPACK version 2 codes.           |
# %-------------------------------------------------------------------%
#
#DIRS   = $(LAPACKdir) $(UTILdir) $(SRCdir)
#

#
# %---------------------------------------------------%
# | The name of the libraries to be created/linked to |
# %---------------------------------------------------%
#

ARPACKLIB  = $(home)/libarpack_$(PLAT).a
LAPACKLIB = 
BLASLIB = 

ALIBS =  $(ARPACKLIB) $(LAPACKLIB) $(BLASLIB) 

#
# %-----------------------------------------------------------%
# | Libraries needed for Parallel ARPACK - MPI-BLACS for SUN4 |
# %-----------------------------------------------------------%
#

PARPACKLIB = $(home)/parpack_$(COMMLIB)-$(PLAT).a

# MPI_BLACS for LINUX
#BLACSLIBS = $(libdir)/blacs_MPI-LINUX-0.a -lmpi
BLACSLIBS = $(libdir)/blacsF77init_MPI-LINUX-0.a $(libdir)/blacs_MPI-LINUX-0.a \
	$(libdir)/blacsF77init_MPI-LINUX-0.a

PLIBS = $(PARPACKLIB) $(ALIBS) $(BLACSLIBS)

#
# %---------------------------------------------------------%
# |                  SECTION 2: COMPILERS                   |
# |                                                         |
# | The following macros specify compilers, linker/loaders, |
# | the archiver, and their options.  You need to make sure |
# | these are correct for your system.                      |
# %---------------------------------------------------------%
#
#
# %------------------------------%
# | Make our own suffixes' list. |
# %------------------------------%
#
.SUFFIXES:
.SUFFIXES:	.f	.o

#
# %------------------%
# | Default command. |
# %------------------%
#
.DEFAULT:
	@$(ECHO) "Unknown target $@, try:  make help"

#
# %-------------------------------------------%
# |  Command to build .o files from .f files. |
# %-------------------------------------------%
#
.f.o:
	@$(ECHO) Making $@ from $<
	@$(FC) -c $(FFLAGS) $<

#
# %-----------------------------------------%
# | Various compilation programs and flags. |
# | You need to make sure these are correct |
# | for your system.                        |
# %-----------------------------------------%
#
FC      = f77
FFLAGS  = (OPTFLAGS)

#
# %-----------------------------------%
# | Set the parallel fortran compiler |
# %-----------------------------------%
#
PFC     = mpif77    #mpich implementations
PFFLAGS = (OPTFLAGS)

LDFLAGS = 
CD		= cd

ECHO	 = echo

LN	 = ln
LNFLAGS	 = -s

MAKE	 = make

RM	 = rm
RMFLAGS  = -f

SHELL	 = /bin/sh

#
#  %----------------------------------------------------------------%
#  | The archiver and the flag(s) to use when building an archive   |
#  | (library).  Also the ranlib routine.  If your system has no    |
#  | ranlib, set RANLIB = touch.                                    |
#  %----------------------------------------------------------------%
#
AR = ar
ARFLAGS = r

#RANLIB  = touch
RANLIB   = ranlib
#
# %----------------------------------%
# | This is the general help target. |
# %----------------------------------%
#
help:
	@$(ECHO) "usage: make ?"
